@@ -4,20 +4,18 @@ use 5.006;
 use strict;
 use warnings;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
+use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = sprintf "%d.%02d", '$Revision: 1.1 $ ' =~ /(\d+)\.(\d+)/;
+our $VERSION = "1.81";
 
-use LWP;
 use Carp;
 
 # Preloaded methods go here.
-sub makeashorterlink {
+sub makeashorterlink ($)
+{
   my $masl = 'http://www.makeashorterlink.com/index.php';
   my $url = shift or croak 'No URL passed to makeashorterlink';
-  my $ua = shift || LWP::UserAgent->new();
+  my $ua = __PACKAGE__->ua();
 
   my $resp = $ua->post($masl,
                        [ url => $url ]);
@@ -25,14 +23,18 @@ sub makeashorterlink {
   return unless $resp->is_success;
 
   if ($resp->content =~ m!Your shorter link is: <a href="(.*)">!) {
-    return $1;
+      return $1;
+  } elsif ($resp->content =~ m!<h2>URL already short:</h2>!) {
+      return $url;
   }
+  return;
 }
 
-sub makealongerlink {
+sub makealongerlink ($)
+{
   my $masl_url = shift 
     or croak 'No MASL key / URL passed to makealongerlink';
-  my $ua = shift || LWP::UserAgent->new(requests_redirectable => []);
+  my $ua = __PACKAGE__->ua();
 
   $masl_url = "http://www.makeashorterlink.com/?$masl_url"
     unless $masl_url =~ m!^http://!i;
@@ -81,15 +83,23 @@ The function C<makealongerlink> does the reverse. C<makealongerlink>
 will accept as an argument either the full MASL URL or just the MASL
 identifier.
 
-If anything goes wrong, then either function will return C<undef>.
+If the URL to be shortened is already as short, or shorter, than how
+MASL would make it, then the URL you gave is returned. If anything else
+goes wrong, then either function will return C<undef>.
 
 For more information, see L<WWW::Shorten>.
 
-
 =head2 EXPORT
 
 makeashorterlink, makealongerlink
 
+=head1 BUGS, REQUESTS, COMMENTS
+
+Please report any requests, suggestions or bugs via the system at
+L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
+This makes it much easier for me to track things and thus means
+your problem is less likely to be neglected.
+
 =head1 AUTHOR
 
 Dave Cross <dave@dave.org.uk>
