@@ -4,32 +4,35 @@ use 5.006;
 use strict;
 use warnings;
 
-require Exporter;
+use base qw( WWW::Shorten::generic Exporter );
+our @EXPORT = qw( makeashorterlink makealongerlink );
+our $VERSION = "1.81";
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw(makeashorterlink makealongerlink);
-our ($VERSION) = q$Revision: 1.1 $ =~ /^ Revision: \s+ (\S+) \s+ $/x;
-
-use LWP;
 use Carp;
 
-sub makeashorterlink
+sub makeashorterlink ($)
 {
     my $url = shift or croak 'No URL passed to makeashorterlink';
-    my $ua = shift || LWP::UserAgent->new();
-    my $tinyurl = 'http://tinyurl.com/create.php';
-    my $resp = $ua->post($tinyurl, [ url => $url ]);
-    return unless $resp->is_success;
-    if ($resp->content =~ m!> (\Qhttp://tinyurl.com/\E\w+) <!x) {
+    my $ua = __PACKAGE__->ua();
+    my $tinyurl = 'http://tinyurl.com/api-create.php';
+    my $resp = $ua->post($tinyurl, [
+	url => $url,
+	source => "PerlAPI-$VERSION",
+	]);
+    return undef unless $resp->is_success;
+    my $content = $resp->content;
+    return undef if $content =~ /Error/;
+    if ($resp->content =~ m!(\Qhttp://tinyurl.com/\E\w+)!x) {
 	return $1;
     }
+    return;
 }
 
-sub makealongerlink
+sub makealongerlink ($)
 {
     my $tinyurl_url = shift 
 	or croak 'No TinyURL key / URL passed to makealongerlink';
-    my $ua = shift || LWP::UserAgent->new(requests_redirectable => []);
+    my $ua = __PACKAGE__->ua();
 
     $tinyurl_url = "http://tinyurl.com/$tinyurl_url"
     unless $tinyurl_url =~ m!^http://!i;
@@ -78,11 +81,23 @@ If anything goes wrong, then either function will return C<undef>.
 
 makeashorterlink, makealongerlink
 
+=head1 BUGS, REQUESTS, COMMENTS
+
+Please report any requests, suggestions or bugs via the system at
+L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
+This makes it much easier for me to track things and thus means
+your problem is less likely to be neglected.
+
+=head1 THANKS
+
+Thanks to Kevin Gilbertson (Gilby) for information on the TinyURL API
+interface.
+
 =head1 AUTHOR
 
 Iain Truskett <spoon@cpan.org>
 
-Based on WWW::MakeAShorteRLink by Dave Cross <dave@dave.org.uk>
+Based on WWW::MakeAShorterLink by Dave Cross <dave@dave.org.uk>
 
 =head1 SEE ALSO
 
